summaryrefslogtreecommitdiff
path: root/gst-libs/gst/vulkan
diff options
context:
space:
mode:
authorMatthew Waters <matthew@centricular.com>2019-11-29 11:05:50 +1100
committerMatthew Waters <matthew@centricular.com>2019-12-04 07:20:27 +0000
commitdee29aa8e7d6b2cc899f6c82c94373c9f9e5d86e (patch)
tree829c6fb80c39b6107c62963c848f4753d25c623d /gst-libs/gst/vulkan
parent812d593c4e0b404e3cb940725ac6815895efbee1 (diff)
downloadgstreamer-plugins-bad-dee29aa8e7d6b2cc899f6c82c94373c9f9e5d86e.tar.gz
vulkan: fix up some gir annotations
Diffstat (limited to 'gst-libs/gst/vulkan')
-rw-r--r--gst-libs/gst/vulkan/gstvkimagememory.c10
-rw-r--r--gst-libs/gst/vulkan/gstvkphysicaldevice.c18
-rw-r--r--gst-libs/gst/vulkan/gstvktrash.c12
3 files changed, 32 insertions, 8 deletions
diff --git a/gst-libs/gst/vulkan/gstvkphysicaldevice.c b/gst-libs/gst/vulkan/gstvkphysicaldevice.c
index 01f0978e4..9091cb2f6 100644
--- a/gst-libs/gst/vulkan/gstvkphysicaldevice.c
+++ b/gst-libs/gst/vulkan/gstvkphysicaldevice.c
@@ -625,7 +625,7 @@ error:
}
/**
- * gst_vulkan_physical_device_get_physical_device: (skip)
+ * gst_vulkan_physical_device_get_handle: (skip)
* @device: a #GstVulkanPhysicalDevice
*
* Returns: The associated `VkPhysicalDevice` handle
@@ -639,3 +639,19 @@ gst_vulkan_physical_device_get_handle (GstVulkanPhysicalDevice * device)
return device->device;
}
+
+/**
+ * gst_vulkan_physical_device_get_instance:
+ * @device: a #GstVulkanPhysicalDevice
+ *
+ * Returns: (transfer full): The #GstVulkanInstance associated with this physical device
+ *
+ * Since: 1.18
+ */
+GstVulkanInstance *
+gst_vulkan_physical_device_get_instance (GstVulkanPhysicalDevice * device)
+{
+ g_return_val_if_fail (GST_IS_VULKAN_PHYSICAL_DEVICE (device), NULL);
+
+ return device->instance ? gst_object_ref (device->instance) : NULL;
+}
diff --git a/gst-libs/gst/vulkan/gstvktrash.c b/gst-libs/gst/vulkan/gstvktrash.c
index abce93c1f..ac840e700 100644
--- a/gst-libs/gst/vulkan/gstvktrash.c
+++ b/gst-libs/gst/vulkan/gstvktrash.c
@@ -54,7 +54,7 @@ gst_vulkan_trash_dispose (GstVulkanTrash * trash)
/* keep the buffer alive */
gst_vulkan_trash_ref (trash);
- /* return the buffer to the pool */
+ /* return the trash object to the pool */
gst_vulkan_trash_release (cache, trash);
return FALSE;
@@ -299,6 +299,16 @@ gst_vulkan_trash_list_init (GstVulkanTrashList * trash_list)
{
}
+/**
+ * gst_vulkan_trash_list_acquire:
+ * @trash_list: a #GstVulkanTrashList
+ * @fence: a #GstVulkanFence to wait for signalling
+ * @notify: (scope async): notify function for when @fence is signalled
+ * @user_data: user data for @notify
+ *
+ * Returns: (transfer full): a new or reused #GstVulkanTrash for the provided
+ * parameters.
+ */
GstVulkanTrash *
gst_vulkan_trash_list_acquire (GstVulkanTrashList * trash_list,
GstVulkanFence * fence, GstVulkanTrashNotify notify, gpointer user_data)
diff --git a/gst-libs/gst/vulkan/gstvkimagememory.c b/gst-libs/gst/vulkan/gstvkimagememory.c
index 653a59f26..6cdd04253 100644
--- a/gst-libs/gst/vulkan/gstvkimagememory.c
+++ b/gst-libs/gst/vulkan/gstvkimagememory.c
@@ -568,8 +568,6 @@ gst_vulkan_image_memory_release_view (GstVulkanImageMemory * image,
* @image: a #GstVulkanImageMemory
* @view: a #GstVulkanImageView
*
- * Return: the height of @image
- *
* Since: 1.18
*/
void
@@ -620,8 +618,8 @@ find_view_func (GstVulkanImageView * view, gpointer user_data)
/**
* gst_vulkan_image_memory_find_view:
* @image: a #GstVulkanImageMemory
* @find_func: #GstVulkanImageMemoryFindViewFunc to search with
* @data: user data to call @finc_func with
*
* Return: (transfer full): the first #GstVulkanImageView that @find_func
* returns %TRUE for, or %NULL
@@ -630,7 +628,7 @@ find_view_func (GstVulkanImageView * view, gpointer user_data)
*/
GstVulkanImageView *
gst_vulkan_image_memory_find_view (GstVulkanImageMemory * image,
- GstVulkanImageMemoryFindViewFunc find_func, gpointer data)
+ GstVulkanImageMemoryFindViewFunc find_func, gpointer user_data)
{
GstVulkanImageView *ret = NULL;
struct view_data view;
@@ -643,7 +641,7 @@ gst_vulkan_image_memory_find_view (GstVulkanImageMemory * image,
g_mutex_lock (&image->lock);
view.img = image;
view.find_func = find_func;
- view.find_data = data;
+ view.find_data = user_data;
if (g_ptr_array_find_with_equal_func (image->outstanding_views, &view,
(GEqualFunc) find_view_func, &index)) {
@@ -620,8 +618,8 @@ find_view_func (GstVulkanImageView * view, gpointer user_data)
* gst_vulkan_image_memory_find_view:
* @image: a #GstVulkanImageMemory
- * @find_func: #GstVulkanImageMemoryFindViewFunc to search with
- * @data: user data to call @finc_func with
+ * @find_func: (scope call): #GstVulkanImageMemoryFindViewFunc to search with
+ * @user_data: user data to call @finc_func with
*
* Return: (transfer full): the first #GstVulkanImageView that @find_func